@@ -13,7 +13,8 @@ test_that(
   desc = "test functioning of hyperbolic regression function",
   code = {
 
-    skip_on_cran()
+    local_edition(3)
+    #"skip_on_cran()
 
     # calibration data
     cal_type_1 <- fread("./testdata/cal_type_1.csv")
@@ -25,10 +26,13 @@ test_that(
                                 logfilename,
                                 minmax = TRUE,
                                 seed = 1234)
-    expect_error({
-      expect_known_hash(h1, "3578c7d484")
-      expect_known_hash(h1, "bce2d004e7")
-    }, class = "error", regexp = "3578c7d484|bce2d004e7") # bce2d004e7
+    expect_snapshot_value(
+      x = h1,
+      style = "serialize",
+      cran = FALSE,
+      tolerance = 10e-3,
+      ignore_function_env = TRUE
+    )
 
     expect_true(file.remove(paste0(prefix, "/log.txt")))
   })
